@@ -2,11 +2,12 @@ import websocket
 
 if __name__ == "__main__":
     websocket.enableTrace(True)
-    ws = websocket.create_connection("ws://echo.websocket.org/")
+    ws = websocket.create_connection("ws://echo.websocket.events/")
+    ws.recv()
     print("Sending 'Hello, World'...")
     ws.send("Hello, World")
     print("Sent")
     print("Receiving...")
     result = ws.recv()
-    print("Received '%s'" % result)
+    print(f"Received '{result}'")
     ws.close()
