@@ -1,10 +1,8 @@
-import websocket
-try:
-    import thread
-except ImportError:  #TODO use Threading instead of _thread in python3
-    import _thread as thread
-import time
 import sys
+import time
+from threading import Thread
+
+import websocket
 
 
 def on_message(ws, message):
@@ -15,7 +13,7 @@ def on_error(ws, error):
     print(error)
 
 
-def on_close(ws):
+def on_close(ws, close_status_code, close_msg):
     print("### closed ###")
 
 
@@ -32,17 +30,17 @@ def on_open(ws):
         ws.close()
         print("Thread terminating...")
 
-    thread.start_new_thread(run, ())
+    Thread(target=run).start()
+
 
 if __name__ == "__main__":
     websocket.enableTrace(True)
     if len(sys.argv) < 2:
-        host = "ws://echo.websocket.org/"
+        host = "ws://echo.websocket.events/"
     else:
         host = sys.argv[1]
-    ws = websocket.WebSocketApp(host,
-                                on_message = on_message,
-                                on_error = on_error,
-                                on_close = on_close)
+    ws = websocket.WebSocketApp(
+        host, on_message=on_message, on_error=on_error, on_close=on_close
+    )
     ws.on_open = on_open
     ws.run_forever()
