@@ -2,7 +2,7 @@
 _exceptions.py
 websocket - WebSocket client library for Python
 
-Copyright 2022 engn33r
+Copyright 2023 engn33r
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -22,6 +22,7 @@ class WebSocketException(Exception):
     """
     WebSocket exception class.
     """
+
     pass
 
 
@@ -29,6 +30,7 @@ class WebSocketProtocolException(WebSocketException):
     """
     If the WebSocket protocol is invalid, this exception will be raised.
     """
+
     pass
 
 
@@ -36,6 +38,7 @@ class WebSocketPayloadException(WebSocketException):
     """
     If the WebSocket payload is invalid, this exception will be raised.
     """
+
     pass
 
 
@@ -44,6 +47,7 @@ class WebSocketConnectionClosedException(WebSocketException):
     If remote host closed the connection or some network error happened,
     this exception will be raised.
     """
+
     pass
 
 
@@ -51,6 +55,7 @@ class WebSocketTimeoutException(WebSocketException):
     """
     WebSocketTimeoutException will be raised at socket timeout during read/write data.
     """
+
     pass
 
 
@@ -58,6 +63,7 @@ class WebSocketProxyException(WebSocketException):
     """
     WebSocketProxyException will be raised when proxy error occurred.
     """
+
     pass
 
 
@@ -66,15 +72,23 @@ class WebSocketBadStatusException(WebSocketException):
     WebSocketBadStatusException will be raised when we get bad handshake status code.
     """
 
-    def __init__(self, message, status_code, status_message=None, resp_headers=None):
-        msg = message % (status_code, status_message)
-        super().__init__(msg)
+    def __init__(
+        self,
+        message: str,
+        status_code: int,
+        status_message=None,
+        resp_headers=None,
+        resp_body=None,
+    ):
+        super().__init__(message)
         self.status_code = status_code
         self.resp_headers = resp_headers
+        self.resp_body = resp_body
 
 
 class WebSocketAddressException(WebSocketException):
     """
     If the websocket address info cannot be found, this exception will be raised.
     """
+
     pass
